#[non_exhaustive]pub struct BoundaryLineGeneration {
pub voltage_regulation_on: bool,
pub minimum_active_power_mw: Option<f64>,
pub maximum_active_power_mw: Option<f64>,
pub target_active_power_mw: Option<f64>,
pub target_reactive_power_mvar: Option<f64>,
pub target_voltage_kv: Option<f64>,
pub reactive_limits: Option<ReactiveLimits>,
}Expand description
Optional generation attached to a PowSybl boundary line.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.voltage_regulation_on: boolminimum_active_power_mw: Option<f64>maximum_active_power_mw: Option<f64>target_active_power_mw: Option<f64>target_reactive_power_mvar: Option<f64>target_voltage_kv: Option<f64>reactive_limits: Option<ReactiveLimits>Trait Implementations
Sourceimpl Clone for BoundaryLineGeneration
impl Clone for BoundaryLineGeneration
Sourcefn clone(&self) -> BoundaryLineGeneration
fn clone(&self) -> BoundaryLineGeneration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BoundaryLineGeneration
impl Debug for BoundaryLineGeneration
Sourceimpl<'de> Deserialize<'de> for BoundaryLineGeneration
impl<'de> Deserialize<'de> for BoundaryLineGeneration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BoundaryLineGeneration
impl JsonSchema for BoundaryLineGeneration
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BoundaryLineGeneration
impl PartialEq for BoundaryLineGeneration
Sourcefn eq(&self, other: &BoundaryLineGeneration) -> bool
fn eq(&self, other: &BoundaryLineGeneration) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BoundaryLineGeneration
impl Serialize for BoundaryLineGeneration
impl StructuralPartialEq for BoundaryLineGeneration