#[non_exhaustive]pub struct BusBreakerBus {
pub component: ComponentId,
pub voltage_level: ComponentId,
pub calculated_bus: Option<BusId>,
pub voltage_kv: Option<f64>,
pub angle_degrees: Option<f64>,
}Expand description
One configured bus in a bus breaker voltage level and the energized bus it contributes to in the balanced calculation view.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdvoltage_level: ComponentIdcalculated_bus: Option<BusId>voltage_kv: Option<f64>angle_degrees: Option<f64>Trait Implementations
Sourceimpl Clone for BusBreakerBus
impl Clone for BusBreakerBus
Sourcefn clone(&self) -> BusBreakerBus
fn clone(&self) -> BusBreakerBus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BusBreakerBus
impl Debug for BusBreakerBus
Sourceimpl<'de> Deserialize<'de> for BusBreakerBus
impl<'de> Deserialize<'de> for BusBreakerBus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BusBreakerBus
impl JsonSchema for BusBreakerBus
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BusBreakerBus
impl PartialEq for BusBreakerBus
Sourcefn eq(&self, other: &BusBreakerBus) -> bool
fn eq(&self, other: &BusBreakerBus) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BusBreakerBus
impl Serialize for BusBreakerBus
impl StructuralPartialEq for BusBreakerBus