#[non_exhaustive]pub struct BusbarSection {
pub component: ComponentId,
pub voltage_level: ComponentId,
pub node: ComponentId,
}Expand description
A busbar section attached to a node breaker connectivity node.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdvoltage_level: ComponentIdnode: ComponentIdTrait Implementations
Sourceimpl Clone for BusbarSection
impl Clone for BusbarSection
Sourcefn clone(&self) -> BusbarSection
fn clone(&self) -> BusbarSection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BusbarSection
impl Debug for BusbarSection
Sourceimpl<'de> Deserialize<'de> for BusbarSection
impl<'de> Deserialize<'de> for BusbarSection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BusbarSection
Sourceimpl JsonSchema for BusbarSection
impl JsonSchema for BusbarSection
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BusbarSection
impl PartialEq for BusbarSection
Sourcefn eq(&self, other: &BusbarSection) -> bool
fn eq(&self, other: &BusbarSection) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BusbarSection
impl Serialize for BusbarSection
impl StructuralPartialEq for BusbarSection