#[non_exhaustive]pub struct CaseMetadata {
pub case_date: Option<String>,
pub forecast_distance: Option<i32>,
pub source_model_format: Option<String>,
pub minimum_validation_level: Option<String>,
}Expand description
Source neutral case metadata recorded by a grid exchange format.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.case_date: Option<String>forecast_distance: Option<i32>source_model_format: Option<String>minimum_validation_level: Option<String>Trait Implementations
Sourceimpl Clone for CaseMetadata
impl Clone for CaseMetadata
Sourcefn clone(&self) -> CaseMetadata
fn clone(&self) -> CaseMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CaseMetadata
impl Debug for CaseMetadata
Sourceimpl Default for CaseMetadata
impl Default for CaseMetadata
Sourcefn default() -> CaseMetadata
fn default() -> CaseMetadata
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CaseMetadata
impl<'de> Deserialize<'de> for CaseMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CaseMetadata
Sourceimpl JsonSchema for CaseMetadata
impl JsonSchema for CaseMetadata
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CaseMetadata
impl PartialEq for CaseMetadata
Sourcefn eq(&self, other: &CaseMetadata) -> bool
fn eq(&self, other: &CaseMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CaseMetadata
impl Serialize for CaseMetadata
impl StructuralPartialEq for CaseMetadata