#[non_exhaustive]pub struct ConnectivityNode {
pub component: ComponentId,
pub voltage_level: ComponentId,
pub node_number: Option<i32>,
pub calculated_bus: Option<BusId>,
}Expand description
One connectivity node in a node breaker voltage level.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdvoltage_level: ComponentIdnode_number: Option<i32>Integer node number when the source uses node breaker numbering, as in XIIDM and RAWX. Identity based sources such as CGMES leave this unset.
calculated_bus: Option<BusId>The energized bus in the balanced calculation view, when one is known.