#[non_exhaustive]pub struct DcBusbar {
pub component: ComponentId,
pub equipment_container: Option<ComponentId>,
pub dc_terminal: DcTerminal,
pub rated_dc_voltage_kv: Option<f64>,
}Expand description
A CGMES DC busbar.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdequipment_container: Option<ComponentId>dc_terminal: DcTerminalrated_dc_voltage_kv: Option<f64>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for DcBusbar
impl<'de> Deserialize<'de> for DcBusbar
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DcBusbar
impl JsonSchema for DcBusbar
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DcBusbar