#[non_exhaustive]pub struct DcConverterUnit {
pub component: ComponentId,
pub substation: Option<ComponentId>,
pub operation_mode: DcConverterOperatingMode,
}Expand description
A CGMES DC converter unit and its substation containment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdsubstation: Option<ComponentId>operation_mode: DcConverterOperatingModeTrait Implementations
Sourceimpl Clone for DcConverterUnit
impl Clone for DcConverterUnit
Sourcefn clone(&self) -> DcConverterUnit
fn clone(&self) -> DcConverterUnit
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DcConverterUnit
impl Debug for DcConverterUnit
Sourceimpl<'de> Deserialize<'de> for DcConverterUnit
impl<'de> Deserialize<'de> for DcConverterUnit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DcConverterUnit
Sourceimpl JsonSchema for DcConverterUnit
impl JsonSchema for DcConverterUnit
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DcConverterUnit
impl PartialEq for DcConverterUnit
Sourcefn eq(&self, other: &DcConverterUnit) -> bool
fn eq(&self, other: &DcConverterUnit) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DcConverterUnit
impl Serialize for DcConverterUnit
impl StructuralPartialEq for DcConverterUnit