#[non_exhaustive]pub struct DcSwitch {
pub component: ComponentId,
pub equipment_container: Option<ComponentId>,
pub dc_terminal1: DcTerminal,
pub dc_terminal2: DcTerminal,
pub kind: DcSwitchKind,
pub rated_dc_voltage_kv: Option<f64>,
pub open: Option<bool>,
pub resistance_ohm: Option<f64>,
}Expand description
A switch between two DC nodes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdequipment_container: Option<ComponentId>dc_terminal1: DcTerminaldc_terminal2: DcTerminalkind: DcSwitchKindrated_dc_voltage_kv: Option<f64>open: Option<bool>resistance_ohm: Option<f64>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for DcSwitch
impl<'de> Deserialize<'de> for DcSwitch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DcSwitch
impl JsonSchema for DcSwitch
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DcSwitch