DetailedConnectivity

Struct DetailedConnectivity 

#[non_exhaustive]
pub struct DetailedConnectivity {
Show 28 fields pub omitted_fields: Vec<OmittedField>, pub component_metadata: Vec<ComponentMetadata>, pub subnetworks: Vec<Subnetwork>, pub substations: Vec<Substation>, pub voltage_levels: Vec<VoltageLevel>, pub bus_breaker_buses: Vec<BusBreakerBus>, pub calculated_buses: Vec<CalculatedBus>, pub connectivity_nodes: Vec<ConnectivityNode>, pub busbar_sections: Vec<BusbarSection>, pub junctions: Vec<Junction>, pub terminals: Vec<Terminal>, pub switches: Vec<TopologySwitch>, pub internal_connections: Vec<InternalConnection>, pub operational_limit_groups: Vec<OperationalLimitGroup>, pub tap_changers: Vec<TapChanger>, pub equipment_reactive_limits: Vec<EquipmentReactiveLimits>, pub boundary_lines: Vec<BoundaryLine>, pub tie_lines: Vec<TieLine>, pub dc_converter_units: Vec<DcConverterUnit>, pub dc_topological_nodes: Vec<DcTopologicalNode>, pub dc_nodes: Vec<DcNode>, pub dc_grounds: Vec<DcGround>, pub dc_busbars: Vec<DcBusbar>, pub dc_lines: Vec<DcLine>, pub dc_series_devices: Vec<DcSeriesDevice>, pub dc_switches: Vec<DcSwitch>, pub voltage_source_converters: Vec<VoltageSourceConverter>, pub line_commutated_converters: Vec<LineCommutatedConverter>,
}
Source neutral hierarchy and detailed connectivity retained beside the balanced calculation view.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
omitted_fields: Vec<OmittedField>

Source fields whose absence must remain distinct from an explicit numeric zero or default value during fresh emission.

component_metadata: Vec<ComponentMetadata>subnetworks: Vec<Subnetwork>substations: Vec<Substation>voltage_levels: Vec<VoltageLevel>bus_breaker_buses: Vec<BusBreakerBus>calculated_buses: Vec<CalculatedBus>connectivity_nodes: Vec<ConnectivityNode>busbar_sections: Vec<BusbarSection>junctions: Vec<Junction>terminals: Vec<Terminal>switches: Vec<TopologySwitch>internal_connections: Vec<InternalConnection>operational_limit_groups: Vec<OperationalLimitGroup>tap_changers: Vec<TapChanger>equipment_reactive_limits: Vec<EquipmentReactiveLimits>boundary_lines: Vec<BoundaryLine>tie_lines: Vec<TieLine>dc_converter_units: Vec<DcConverterUnit>dc_topological_nodes: Vec<DcTopologicalNode>dc_nodes: Vec<DcNode>dc_grounds: Vec<DcGround>dc_busbars: Vec<DcBusbar>dc_lines: Vec<DcLine>dc_series_devices: Vec<DcSeriesDevice>dc_switches: Vec<DcSwitch>voltage_source_converters: Vec<VoltageSourceConverter>line_commutated_converters: Vec<LineCommutatedConverter>