#[non_exhaustive]pub struct DroopCurveSegment {
pub minimum_voltage_kv: f64,
pub maximum_voltage_kv: f64,
pub k: f64,
}Expand description
One segment of an AC/DC converter’s DC voltage droop curve.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.minimum_voltage_kv: f64maximum_voltage_kv: f64k: f64Trait Implementations
Sourceimpl Clone for DroopCurveSegment
impl Clone for DroopCurveSegment
Sourcefn clone(&self) -> DroopCurveSegment
fn clone(&self) -> DroopCurveSegment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DroopCurveSegment
impl Debug for DroopCurveSegment
Sourceimpl<'de> Deserialize<'de> for DroopCurveSegment
impl<'de> Deserialize<'de> for DroopCurveSegment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DroopCurveSegment
impl JsonSchema for DroopCurveSegment
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DroopCurveSegment
impl PartialEq for DroopCurveSegment
Sourcefn eq(&self, other: &DroopCurveSegment) -> bool
fn eq(&self, other: &DroopCurveSegment) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DroopCurveSegment
impl Serialize for DroopCurveSegment
impl StructuralPartialEq for DroopCurveSegment