#[non_exhaustive]pub struct ExternalIdentifier {
pub value: String,
pub authority: Option<String>,
}Expand description
An identifier assigned by another data system or authority.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.value: StringTrait Implementations
Sourceimpl Clone for ExternalIdentifier
impl Clone for ExternalIdentifier
Sourcefn clone(&self) -> ExternalIdentifier
fn clone(&self) -> ExternalIdentifier
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExternalIdentifier
impl Debug for ExternalIdentifier
Sourceimpl<'de> Deserialize<'de> for ExternalIdentifier
impl<'de> Deserialize<'de> for ExternalIdentifier
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExternalIdentifier
Sourceimpl JsonSchema for ExternalIdentifier
impl JsonSchema for ExternalIdentifier
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExternalIdentifier
impl PartialEq for ExternalIdentifier
Sourcefn eq(&self, other: &ExternalIdentifier) -> bool
fn eq(&self, other: &ExternalIdentifier) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ExternalIdentifier
impl Serialize for ExternalIdentifier
impl StructuralPartialEq for ExternalIdentifier