#[non_exhaustive]pub struct InternalConnection {
pub voltage_level: ComponentId,
pub node1: ComponentId,
pub node2: ComponentId,
}Expand description
A permanent connection between two node breaker connectivity nodes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.voltage_level: ComponentIdnode1: ComponentIdnode2: ComponentIdTrait Implementations
Sourceimpl Clone for InternalConnection
impl Clone for InternalConnection
Sourcefn clone(&self) -> InternalConnection
fn clone(&self) -> InternalConnection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InternalConnection
impl Debug for InternalConnection
Sourceimpl<'de> Deserialize<'de> for InternalConnection
impl<'de> Deserialize<'de> for InternalConnection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for InternalConnection
Sourceimpl JsonSchema for InternalConnection
impl JsonSchema for InternalConnection
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InternalConnection
impl PartialEq for InternalConnection
Sourcefn eq(&self, other: &InternalConnection) -> bool
fn eq(&self, other: &InternalConnection) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for InternalConnection
impl Serialize for InternalConnection
impl StructuralPartialEq for InternalConnection