#[non_exhaustive]pub struct LineCommutatedConverter {Show 39 fields
pub component: ComponentId,
pub dc_converter_unit: Option<ComponentId>,
pub dc_terminal1: DcTerminal,
pub dc_terminal2: DcTerminal,
pub base_apparent_power_mva: Option<f64>,
pub minimum_active_power_mw: Option<f64>,
pub maximum_active_power_mw: Option<f64>,
pub minimum_dc_voltage_kv: Option<f64>,
pub maximum_dc_voltage_kv: Option<f64>,
pub rated_dc_voltage_kv: Option<f64>,
pub valve_u0_kv: Option<f64>,
pub number_of_valves: Option<u32>,
pub idle_loss_mw: Option<f64>,
pub switching_loss_mw_per_ampere: Option<f64>,
pub resistive_loss_ohm: Option<f64>,
pub control_mode: Option<AcDcConverterControlMode>,
pub active_power_at_pcc_mw: Option<f64>,
pub reactive_power_at_pcc_mvar: Option<f64>,
pub target_active_power_mw: Option<f64>,
pub target_dc_voltage_kv: Option<f64>,
pub pcc_terminal: Option<TerminalReference>,
pub droop_curve: Option<DroopCurve>,
pub reactive_model: Option<LineCommutatedConverterReactiveModel>,
pub power_factor: Option<f64>,
pub operating_mode: Option<LineCommutatedConverterOperatingMode>,
pub rated_dc_current_a: Option<f64>,
pub minimum_alpha_degrees: Option<f64>,
pub maximum_alpha_degrees: Option<f64>,
pub minimum_gamma_degrees: Option<f64>,
pub maximum_gamma_degrees: Option<f64>,
pub target_alpha_degrees: Option<f64>,
pub target_gamma_degrees: Option<f64>,
pub target_dc_current_a: Option<f64>,
pub pole_loss_active_power_mw: Option<f64>,
pub dc_current_a: Option<f64>,
pub ac_voltage_kv: Option<f64>,
pub dc_voltage_kv: Option<f64>,
pub alpha_degrees: Option<f64>,
pub gamma_degrees: Option<f64>,
}Expand description
A line commutated converter connected to an AC voltage level and two DC nodes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIddc_converter_unit: Option<ComponentId>dc_terminal1: DcTerminaldc_terminal2: DcTerminalbase_apparent_power_mva: Option<f64>minimum_active_power_mw: Option<f64>maximum_active_power_mw: Option<f64>minimum_dc_voltage_kv: Option<f64>maximum_dc_voltage_kv: Option<f64>rated_dc_voltage_kv: Option<f64>valve_u0_kv: Option<f64>number_of_valves: Option<u32>idle_loss_mw: Option<f64>switching_loss_mw_per_ampere: Option<f64>resistive_loss_ohm: Option<f64>control_mode: Option<AcDcConverterControlMode>active_power_at_pcc_mw: Option<f64>Active power at the point of common coupling, using load sign convention.
reactive_power_at_pcc_mvar: Option<f64>Reactive power at the point of common coupling, using load sign convention.
target_active_power_mw: Option<f64>Active power target at the point of common coupling, using load sign convention.
target_dc_voltage_kv: Option<f64>pcc_terminal: Option<TerminalReference>droop_curve: Option<DroopCurve>reactive_model: Option<LineCommutatedConverterReactiveModel>power_factor: Option<f64>operating_mode: Option<LineCommutatedConverterOperatingMode>rated_dc_current_a: Option<f64>minimum_alpha_degrees: Option<f64>maximum_alpha_degrees: Option<f64>minimum_gamma_degrees: Option<f64>maximum_gamma_degrees: Option<f64>target_alpha_degrees: Option<f64>target_gamma_degrees: Option<f64>target_dc_current_a: Option<f64>pole_loss_active_power_mw: Option<f64>dc_current_a: Option<f64>ac_voltage_kv: Option<f64>dc_voltage_kv: Option<f64>alpha_degrees: Option<f64>gamma_degrees: Option<f64>Trait Implementations
Sourceimpl Clone for LineCommutatedConverter
impl Clone for LineCommutatedConverter
Sourcefn clone(&self) -> LineCommutatedConverter
fn clone(&self) -> LineCommutatedConverter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LineCommutatedConverter
impl Debug for LineCommutatedConverter
Sourceimpl<'de> Deserialize<'de> for LineCommutatedConverter
impl<'de> Deserialize<'de> for LineCommutatedConverter
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LineCommutatedConverter
impl JsonSchema for LineCommutatedConverter
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LineCommutatedConverter
impl PartialEq for LineCommutatedConverter
Sourcefn eq(&self, other: &LineCommutatedConverter) -> bool
fn eq(&self, other: &LineCommutatedConverter) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LineCommutatedConverter
impl Serialize for LineCommutatedConverter
impl StructuralPartialEq for LineCommutatedConverter