#[non_exhaustive]pub struct LoadingLimits {
pub permanent_limit: Option<f64>,
pub permanent_limit_name: Option<String>,
pub temporary_limits: Vec<TemporaryLimit>,
}Expand description
A permanent loading limit and its named temporary limits.
The unit is selected by the field that contains this record: amperes for
current_limits, MW for active_power_limits, and MVA for
apparent_power_limits.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.permanent_limit: Option<f64>permanent_limit_name: Option<String>temporary_limits: Vec<TemporaryLimit>Trait Implementations
Sourceimpl Clone for LoadingLimits
impl Clone for LoadingLimits
Sourcefn clone(&self) -> LoadingLimits
fn clone(&self) -> LoadingLimits
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoadingLimits
impl Debug for LoadingLimits
Sourceimpl Default for LoadingLimits
impl Default for LoadingLimits
Sourcefn default() -> LoadingLimits
fn default() -> LoadingLimits
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for LoadingLimits
impl<'de> Deserialize<'de> for LoadingLimits
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LoadingLimits
impl JsonSchema for LoadingLimits
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LoadingLimits
impl PartialEq for LoadingLimits
Sourcefn eq(&self, other: &LoadingLimits) -> bool
fn eq(&self, other: &LoadingLimits) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LoadingLimits
impl Serialize for LoadingLimits
impl StructuralPartialEq for LoadingLimits