#[non_exhaustive]pub struct OperationalLimitGroup {
pub equipment: ComponentId,
pub terminal: u8,
pub id: String,
pub properties: BTreeMap<String, String>,
pub selected: bool,
pub current_limits: Option<LoadingLimits>,
pub active_power_limits: Option<LoadingLimits>,
pub apparent_power_limits: Option<LoadingLimits>,
}Expand description
One named set of loading limits at an equipment terminal.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.equipment: ComponentIdterminal: u8id: Stringproperties: BTreeMap<String, String>selected: boolcurrent_limits: Option<LoadingLimits>active_power_limits: Option<LoadingLimits>apparent_power_limits: Option<LoadingLimits>Trait Implementations
Sourceimpl Clone for OperationalLimitGroup
impl Clone for OperationalLimitGroup
Sourcefn clone(&self) -> OperationalLimitGroup
fn clone(&self) -> OperationalLimitGroup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OperationalLimitGroup
impl Debug for OperationalLimitGroup
Sourceimpl<'de> Deserialize<'de> for OperationalLimitGroup
impl<'de> Deserialize<'de> for OperationalLimitGroup
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OperationalLimitGroup
impl JsonSchema for OperationalLimitGroup
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OperationalLimitGroup
impl PartialEq for OperationalLimitGroup
Sourcefn eq(&self, other: &OperationalLimitGroup) -> bool
fn eq(&self, other: &OperationalLimitGroup) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OperationalLimitGroup
impl Serialize for OperationalLimitGroup
impl StructuralPartialEq for OperationalLimitGroup