#[non_exhaustive]pub struct ReactiveCapabilityCurvePoint {
pub active_power_mw: f64,
pub minimum_reactive_power_mvar: f64,
pub maximum_reactive_power_mvar: f64,
pub properties: BTreeMap<String, String>,
}Expand description
One point of a reactive capability curve.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.active_power_mw: f64minimum_reactive_power_mvar: f64maximum_reactive_power_mvar: f64properties: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for ReactiveCapabilityCurvePoint
impl Clone for ReactiveCapabilityCurvePoint
Sourcefn clone(&self) -> ReactiveCapabilityCurvePoint
fn clone(&self) -> ReactiveCapabilityCurvePoint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReactiveCapabilityCurvePoint
impl Debug for ReactiveCapabilityCurvePoint
Sourceimpl<'de> Deserialize<'de> for ReactiveCapabilityCurvePoint
impl<'de> Deserialize<'de> for ReactiveCapabilityCurvePoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReactiveCapabilityCurvePoint
impl JsonSchema for ReactiveCapabilityCurvePoint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReactiveCapabilityCurvePoint
impl PartialEq for ReactiveCapabilityCurvePoint
Sourcefn eq(&self, other: &ReactiveCapabilityCurvePoint) -> bool
fn eq(&self, other: &ReactiveCapabilityCurvePoint) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ReactiveCapabilityCurvePoint