#[non_exhaustive]pub struct Subnetwork {
pub component: ComponentId,
pub parent: ComponentId,
pub case_metadata: CaseMetadata,
pub components: Vec<ComponentId>,
}Expand description
One PowSybl subnetwork contained directly by a balanced network.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdparent: ComponentIdcase_metadata: CaseMetadatacomponents: Vec<ComponentId>Trait Implementations
Sourceimpl Clone for Subnetwork
impl Clone for Subnetwork
Sourcefn clone(&self) -> Subnetwork
fn clone(&self) -> Subnetwork
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Subnetwork
impl Debug for Subnetwork
Sourceimpl<'de> Deserialize<'de> for Subnetwork
impl<'de> Deserialize<'de> for Subnetwork
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Subnetwork
Sourceimpl JsonSchema for Subnetwork
impl JsonSchema for Subnetwork
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for Subnetwork
impl PartialEq for Subnetwork
Sourcefn eq(&self, other: &Subnetwork) -> bool
fn eq(&self, other: &Subnetwork) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Subnetwork
impl Serialize for Subnetwork
impl StructuralPartialEq for Subnetwork