#[non_exhaustive]pub struct Substation {
pub component: ComponentId,
pub country: Option<String>,
pub operator: Option<String>,
pub geographical_tags: Vec<String>,
}Expand description
A substation containing one or more voltage levels.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdcountry: Option<String>operator: Option<String>Trait Implementations
Sourceimpl Clone for Substation
impl Clone for Substation
Sourcefn clone(&self) -> Substation
fn clone(&self) -> Substation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Substation
impl Debug for Substation
Sourceimpl<'de> Deserialize<'de> for Substation
impl<'de> Deserialize<'de> for Substation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Substation
Sourceimpl JsonSchema for Substation
impl JsonSchema for Substation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for Substation
impl PartialEq for Substation
Sourcefn eq(&self, other: &Substation) -> bool
fn eq(&self, other: &Substation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Substation
impl Serialize for Substation
impl StructuralPartialEq for Substation