#[non_exhaustive]pub struct TemporaryLimit {
pub name: String,
pub value: f64,
pub acceptable_duration_seconds: u64,
pub fictitious: bool,
}Expand description
One temporary loading limit inside an OperationalLimitGroup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Stringvalue: f64acceptable_duration_seconds: u64fictitious: boolTrait Implementations
Sourceimpl Clone for TemporaryLimit
impl Clone for TemporaryLimit
Sourcefn clone(&self) -> TemporaryLimit
fn clone(&self) -> TemporaryLimit
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TemporaryLimit
impl Debug for TemporaryLimit
Sourceimpl<'de> Deserialize<'de> for TemporaryLimit
impl<'de> Deserialize<'de> for TemporaryLimit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TemporaryLimit
impl JsonSchema for TemporaryLimit
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TemporaryLimit
impl PartialEq for TemporaryLimit
Sourcefn eq(&self, other: &TemporaryLimit) -> bool
fn eq(&self, other: &TemporaryLimit) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TemporaryLimit
impl Serialize for TemporaryLimit
impl StructuralPartialEq for TemporaryLimit