#[non_exhaustive]pub struct TopologySwitch {
pub component: ComponentId,
pub voltage_level: ComponentId,
pub kind: SwitchKind,
pub endpoint1: TopologyEndpoint,
pub endpoint2: TopologyEndpoint,
pub open: bool,
pub retained: bool,
}Expand description
A switch in the authoritative bus breaker or node breaker topology.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdvoltage_level: ComponentIdkind: SwitchKindendpoint1: TopologyEndpointendpoint2: TopologyEndpointopen: boolretained: boolTrait Implementations
Sourceimpl Clone for TopologySwitch
impl Clone for TopologySwitch
Sourcefn clone(&self) -> TopologySwitch
fn clone(&self) -> TopologySwitch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TopologySwitch
impl Debug for TopologySwitch
Sourceimpl<'de> Deserialize<'de> for TopologySwitch
impl<'de> Deserialize<'de> for TopologySwitch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TopologySwitch
Sourceimpl JsonSchema for TopologySwitch
impl JsonSchema for TopologySwitch
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TopologySwitch
impl PartialEq for TopologySwitch
Sourcefn eq(&self, other: &TopologySwitch) -> bool
fn eq(&self, other: &TopologySwitch) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TopologySwitch
impl Serialize for TopologySwitch
impl StructuralPartialEq for TopologySwitch