#[non_exhaustive]pub struct VoltageLevel {
pub component: ComponentId,
pub substation: Option<ComponentId>,
pub nominal_kv: f64,
pub low_voltage_limit_kv: Option<f64>,
pub high_voltage_limit_kv: Option<f64>,
pub topology_kind: TopologyKind,
pub buses: Vec<BusId>,
}Expand description
A voltage level and its voltage limits in kV.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.component: ComponentIdsubstation: Option<ComponentId>nominal_kv: f64low_voltage_limit_kv: Option<f64>high_voltage_limit_kv: Option<f64>topology_kind: TopologyKindbuses: Vec<BusId>Buses in the balanced calculation view that belong to this voltage level.